﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace RSZVL_S_parameter_Measurement_Example
{
    public partial class Dialog : Form
    {
        public Dialog()
        {
            InitializeComponent();
        }

        private void Dialog_Load(object sender, EventArgs e)
        {
            Sin.SelectedIndex = 0;
            Sout.SelectedIndex = 0;
        }

        private void SourcePower_Validating(object sender, CancelEventArgs e)
        {
            Double value = 0.0;

            try
            {
                value = double.Parse(SourcePower.Text);
            }
            catch (Exception ex)
            {
                String my_message;
                my_message = ex.Message;
                MessageBox.Show("Incorrect format of number");
            }
            if (value < -70)
                value = -70.0;

            if (value > 20)
                value = 20.0;

            SourcePower.Text = value.ToString();
        }

        private void Browse_Click(object sender, EventArgs e)
        {
            System.Windows.Forms.SaveFileDialog browse = new System.Windows.Forms.SaveFileDialog();
            if (browse.ShowDialog() == DialogResult.OK)
                Path.Text = browse.FileName.ToString();
        }

        private void Generate_Click(object sender, EventArgs e)
        {
            String window_name = "MeasSetup";
            String trace_name = "MeasTrace";
            Int32 channel = 1;
            Int32 window = 1;
            Int32 window_trace = 2;
            System.Text.StringBuilder catalog = new System.Text.StringBuilder("", 1024);
            System.Text.StringBuilder get_dir = new System.Text.StringBuilder("", 1024);
            System.String cur_dir = "";
            String[] split;
            Int32 i;

            Cursor.Current = System.Windows.Forms.Cursors.WaitCursor;

            try
            {
                // Initialize the driver
                rszvl instrument = new rszvl(ResourceString.Text, IDQuery.Checked, Reset.Checked);
                // Set display update
                instrument.ConfigureDisplayUpdate(Display.Checked, false);
                // Create new window
                instrument.ConfigureNewSetup(window_name);
                // Retrieve the list of traces
                instrument.TraceList(channel, 1024, catalog);

                split = (catalog.ToString()).Split(',');
                if (split.Length > 0) split[0] = split[0].Substring(1);
                for (i = 0; split.Length - i > 0; i+=2)
                {
                    // Delete all possibly opened traces
                    instrument.TraceDelete(channel, split[i]);
                }
                // Create a new trace
                instrument.TraceAdd(channel, trace_name);
                instrument.TraceAssignDiagramArea(window, window_trace, trace_name);
                // Set Sweep parameters
                instrument.ConfigureSweepPoints(channel, Int32.Parse(SweepNumber.Text));
                // Set single sweep and sweep count to 1
                instrument.ConfigureAcquisition(false, 1);
                // Set frequencies
                //!!! Take care of local decimal point !!!
                instrument.ConfigureFrequencyStartStop(Double.Parse(StartFreq.Text), Double.Parse(StopFreq.Text));
                // Set Power
                instrument.ConfigureSourcePower(channel, Double.Parse(SourcePower.Text));
                // Assign a measurement parameter to a trace
                instrument.ConfigureSParameters(channel, trace_name, Int32.Parse(Sout.Text), Int32.Parse(Sin.Text));
                // Initiate measurement
                instrument.Initiate(channel, 30000);
                // Returns the directory for mass memory storage
                instrument.GetCurrentDirectory(get_dir);
                cur_dir = get_dir.ToString();

                split = Path.Text.Split('\\');

                i = 0;
                while (cur_dir.Length>i && ! Char.IsControl(cur_dir, i))
                {
                    i++;
                }

                cur_dir = cur_dir.Substring(0, i);
                cur_dir += "\\";
                cur_dir += split[split.Length - 1];

                // Store trace to file
                instrument.TraceExportData(trace_name, cur_dir);
                // Copy file from instrument
                instrument.ReadToFileFromInstrument(cur_dir, Path.Text);
                // Delete file from instrument
                instrument.FileManagerOperations(3, cur_dir, "");
            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }

            Cursor.Current = System.Windows.Forms.Cursors.Arrow;
        }
    }
}
